==> haskell-bloomfilter-2.0.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bloomfilter
version:              2.0.1.0
visibility:           public
id:                   bloomfilter-2.0.1.0-LDpIpU0R2h8Df5X4IlYooU
key:                  bloomfilter-2.0.1.0-LDpIpU0R2h8Df5X4IlYooU
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            provisional
homepage:             https://github.com/bos/bloomfilter
synopsis:             Pure and impure Bloom Filter implementations.
description:          Pure and impure Bloom Filter implementations.
category:             Data
abi:                  80774f1bc2c10d3a3437b33d9d6ab9fa
exposed:              True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable

hidden-modules:
    Data.BloomFilter.Array Data.BloomFilter.Mutable.Internal
    Data.BloomFilter.Util

import-dirs:          /usr/lib/ghc-8.8.3/site-local/bloomfilter-2.0.1.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/bloomfilter-2.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/bloomfilter-2.0.1.0
hs-libraries:         HSbloomfilter-2.0.1.0-LDpIpU0R2h8Df5X4IlYooU
include-dirs:         /usr/lib/ghc-8.8.3/site-local/bloomfilter-2.0.1.0/include
includes:             lookup3.h
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0 deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html:         /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bloomfilter-2.0.1.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bloomfilter
version:              2.0.1.0
visibility:           public
id:                   bloomfilter-2.0.1.0-Dsnaa73ooapKdvf3wM6Mgx
key:                  bloomfilter-2.0.1.0-Dsnaa73ooapKdvf3wM6Mgx
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            provisional
homepage:             https://github.com/bos/bloomfilter
synopsis:             Pure and impure Bloom Filter implementations.
description:          Pure and impure Bloom Filter implementations.
category:             Data
abi:                  bea3eb9049af7fda549896f0212e222d
exposed:              True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable

hidden-modules:
    Data.BloomFilter.Array Data.BloomFilter.Mutable.Internal
    Data.BloomFilter.Util

import-dirs:          /usr/lib/ghc-8.10.1/site-local/bloomfilter-2.0.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/bloomfilter-2.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/bloomfilter-2.0.1.0
hs-libraries:         HSbloomfilter-2.0.1.0-Dsnaa73ooapKdvf3wM6Mgx
include-dirs:         /usr/lib/ghc-8.10.1/site-local/bloomfilter-2.0.1.0/include
includes:             lookup3.h
depends:
    array-0.5.4.0 base-4.14.0.0 bytestring-0.10.10.0 deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html:         /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
